<?php
/*
Plugin Name: Bulk Price Converter for WooCommerce
Plugin URI: https://wpfactory.com/item/bulk-price-converter-for-woocommerce-plugin/
Description: Bulk price converter for WooCommerce.
Version: 1.4.0
Author: Algoritmika Ltd
Author URI: http://www.algoritmika.com
Text Domain: alg-wc-bulk-price-converter
Domain Path: /langs
Copyright:  2018 Algoritmika Ltd.
WC tested up to: 3.4
License: GNU General Public License v3.0
License URI: http://www.gnu.org/licenses/gpl-3.0.html
*/

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

// Check if WooCommerce is active
$plugin = 'woocommerce/woocommerce.php';
if (
	! in_array( $plugin, apply_filters( 'active_plugins', get_option( 'active_plugins', array() ) ) ) &&
	! ( is_multisite() && array_key_exists( $plugin, get_site_option( 'active_sitewide_plugins', array() ) ) )
) {
	return;
}

if ( 'bulk-price-converter-for-woocommerce.php' === basename( __FILE__ ) ) {
	// Check if Pro is active, if so then return
	$plugin = 'bulk-price-converter-for-woocommerce-pro/bulk-price-converter-for-woocommerce-pro.php';
	if (
		in_array( $plugin, apply_filters( 'active_plugins', get_option( 'active_plugins', array() ) ) ) ||
		( is_multisite() && array_key_exists( $plugin, get_site_option( 'active_sitewide_plugins', array() ) ) )
	) {
		return;
	}
}

if ( ! class_exists( 'Alg_WC_Bulk_Price_Converter' ) ) :

/**
 * Main Alg_WC_Bulk_Price_Converter Class
 *
 * @class   Alg_WC_Bulk_Price_Converter
 * @version 1.4.0
 */
final class Alg_WC_Bulk_Price_Converter {

	/**
	 * Plugin version.
	 *
	 * @var   string
	 * @since 1.2.0
	 */
	public $version = '1.4.0';

	/**
	 * @var Alg_WC_Bulk_Price_Converter The single instance of the class
	 */
	protected static $_instance = null;

	/**
	 * Main Alg_WC_Bulk_Price_Converter Instance
	 *
	 * Ensures only one instance of Alg_WC_Bulk_Price_Converter is loaded or can be loaded.
	 *
	 * @static
	 * @return Alg_WC_Bulk_Price_Converter - Main instance
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * Alg_WC_Bulk_Price_Converter Constructor.
	 *
	 * @version 1.4.0
	 * @access  public
	 */
	function __construct() {

		// Set up localisation
		load_plugin_textdomain( 'bulk-price-converter-for-woocommerce', false, dirname( plugin_basename( __FILE__ ) ) . '/langs/' );

		// Include required files
		$this->includes();

		// Admin
		if ( is_admin() ) {
			add_filter( 'woocommerce_get_settings_pages', array( $this, 'add_woocommerce_settings_tab' ) );
			add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'action_links' ) );
			// Version updated
			if ( get_option( 'alg_wc_bulk_price_converter_version', '' ) !== $this->version ) {
				add_action( 'init', array( $this, 'version_updated' ) );
			}
		}
	}

	/**
	 * Show action links on the plugin screen
	 *
	 * @version 1.4.0
	 * @param   mixed $links
	 * @return  array
	 */
	function action_links( $links ) {
		$custom_links = array();
		$custom_links[] = '<a href="' . admin_url( 'admin.php?page=wc-settings&tab=alg_wc_bulk_price_converter' ) . '">' . __( 'Settings', 'woocommerce' ) . '</a>';
		if ( 'bulk-price-converter-for-woocommerce.php' === basename( __FILE__ ) ) {
			$custom_links[] = '<a href="' . esc_url( 'https://wpfactory.com/item/bulk-price-converter-for-woocommerce-plugin/' ) . '">' .
				__( 'Unlock all', 'bulk-price-converter-for-woocommerce' ) . '</a>';
		}
		return array_merge( $custom_links, $links );
	}

	/**
	 * Include required core files used in admin and on the frontend.
	 *
	 * @version 1.4.0
	 */
	function includes() {
		// Core
		$this->core = require_once( 'includes/class-alg-wc-bulk-price-converter-core.php' );
		// Tool
		require_once( 'includes/class-alg-wc-bulk-price-converter-tool.php' );
		// Settings
		require_once( 'includes/settings/class-alg-wc-bulk-price-converter-settings-section.php' );
		$this->settings = array();
		$this->settings['general'] = require_once( 'includes/settings/class-alg-wc-bulk-price-converter-settings-general.php' );
	}

	/**
	 * version_updated.
	 *
	 * @version 1.4.0
	 * @since   1.4.0
	 */
	function version_updated() {
		foreach ( $this->settings as $section ) {
			foreach ( $section->get_settings() as $value ) {
				if ( isset( $value['default'] ) && isset( $value['id'] ) ) {
					$autoload = isset( $value['autoload'] ) ? ( bool ) $value['autoload'] : true;
					add_option( $value['id'], $value['default'], '', ( $autoload ? 'yes' : 'no' ) );
				}
			}
		}
		update_option( 'alg_wc_bulk_price_converter_version', $this->version );
	}

	/**
	 * Add Bulk Price Converter settings tab to WooCommerce settings.
	 *
	 * @version 1.4.0
	 */
	function add_woocommerce_settings_tab( $settings ) {
		$settings[] = require_once( 'includes/settings/class-wc-settings-bulk-price-converter.php' );
		return $settings;
	}

	/**
	 * Get the plugin url.
	 *
	 * @return string
	 */
	function plugin_url() {
		return untrailingslashit( plugin_dir_url( __FILE__ ) );
	}

	/**
	 * Get the plugin path.
	 *
	 * @return string
	 */
	function plugin_path() {
		return untrailingslashit( plugin_dir_path( __FILE__ ) );
	}

}

endif;

if ( ! function_exists( 'alg_wc_bulk_price_converter' ) ) {
	/**
	 * Returns the main instance of Alg_WC_Bulk_Price_Converter to prevent the need to use globals.
	 *
	 * @return Alg_WC_Bulk_Price_Converter
	 */
	function alg_wc_bulk_price_converter() {
		return Alg_WC_Bulk_Price_Converter::instance();
	}
}

alg_wc_bulk_price_converter();
